Rubik's cube simulation with a built-in tutorial on how to solve the cube.
Includes:
 - Virtual cube, interactive via clickable arrows or keyboard shortcuts
 - General strategy for each step
 - Specific hints for each step
 - Ability to change cube sticker colors (in-progress)
 - Light/Dark Mode (in-progress)

Pip package name: QB-Solver (https://pypi.org/project/QB-solver/)

Install requires: pip packages ursina, rubik-cube, and psd-tools3
 - These can be installed via "pip install ursina rubik-cube psd-tools3"

Run command: "python3 main.py", or "run_simulation" for the pip package

GitHub Repo: https://github.com/a-penton/QB
